@@ -4,12 +4,12 @@ import (
 	"fmt"
 	"path/filepath"
 
-	"github.com/containers/common/pkg/completion"
 	"github.com/containers/podman/v5/cmd/podman/common"
 	"github.com/containers/podman/v5/cmd/podman/registry"
 	"github.com/containers/podman/v5/pkg/domain/entities"
 	"github.com/containers/podman/v5/pkg/domain/utils"
 	"github.com/spf13/cobra"
+	"go.podman.io/common/pkg/completion"
 )
 
 var (
@@ -53,15 +53,22 @@ func init() {
 	appendFlagName := "append"
 	flags.BoolVarP(&addOpts.Append, appendFlagName, "a", false, "Append files to an existing artifact")
 
+	replaceFlagName := "replace"
+	flags.BoolVar(&addOpts.Replace, replaceFlagName, false, "Replace an existing artifact")
+
 	fileMIMETypeFlagName := "file-type"
 	flags.StringVarP(&addOpts.FileMIMEType, fileMIMETypeFlagName, "", "", "Set file type to use for the artifact (layer)")
 	_ = addCmd.RegisterFlagCompletionFunc(fileMIMETypeFlagName, completion.AutocompleteNone)
 }
 
-func add(cmd *cobra.Command, args []string) error {
+func add(_ *cobra.Command, args []string) error {
 	artifactName := args[0]
 	blobs := args[1:]
 
+	if addOpts.Append && addOpts.Replace {
+		return fmt.Errorf("--append and --replace options cannot be used together")
+	}
+
 	annots, err := utils.ParseAnnotations(addOpts.AnnotationsCLI)
 	if err != nil {
 		return err
@@ -72,6 +79,7 @@ func add(cmd *cobra.Command, args []string) error {
 		ArtifactMIMEType: addOpts.ArtifactMIMEType,
 		Append:           addOpts.Append,
 		FileMIMEType:     addOpts.FileMIMEType,
+		Replace:          addOpts.Replace,
 	}
 
 	artifactBlobs := make([]entities.ArtifactBlob, 0, len(blobs))
