@@ -76,10 +76,10 @@ func init() {
 	validate.AddLatestFlag(containerUnmountCommand, &unmountOpts.Latest)
 }
 
-func unmount(cmd *cobra.Command, args []string) error {
+func unmount(_ *cobra.Command, args []string) error {
 	var errs utils.OutputErrors
 	args = utils.RemoveSlash(args)
-	reports, err := registry.ContainerEngine().ContainerUnmount(registry.GetContext(), args, unmountOpts)
+	reports, err := registry.ContainerEngine().ContainerUnmount(registry.Context(), args, unmountOpts)
 	if err != nil {
 		return err
 	}
