@@ -26,8 +26,8 @@ func init() {
 	})
 }
 
-func exists(cmd *cobra.Command, args []string) error {
-	found, err := registry.ContainerEngine().SecretExists(registry.GetContext(), args[0])
+func exists(_ *cobra.Command, args []string) error {
+	found, err := registry.ContainerEngine().SecretExists(registry.Context(), args[0])
 	if err != nil {
 		return err
 	}
