@@ -12,6 +12,8 @@ set -eo pipefail
 set -a
 source /etc/automation_environment
 source $AUTOMATION_LIB_PATH/common_lib.sh
+# shellcheck source=contrib/cirrus/lib.sh
+source $(dirname $0)/lib.sh
 set +a
 
 req_env_vars CI DEST_BRANCH IMAGE_SUFFIX TEST_FLAVOR TEST_ENVIRON \
@@ -43,13 +45,14 @@ get_env_key() {
     python -c "$script"
 }
 
-# Only need to check CI-stuffs on a single build-task, there's only ever
-# one prior-fedora task so use that one.
+# Only need to check CI-stuffs on a single build-task, there's
+# generally one latest fedora task so use that one. In some cases
+# when we have to drop testing for the prior fedora task we may
+# run twice on current fedora but this is not a problem.
 # Envars all defined by CI config.
 # shellcheck disable=SC2154
-if [[ "${DISTRO_NV}" == "$PRIOR_FEDORA_NAME" ]]; then
+if [[ "${DISTRO_NV}" == "$FEDORA_NAME" ]]; then
     msg "Checking shell scripts"
-    showrun ooe.sh dnf install -y ShellCheck  # small/quick addition
     showrun shellcheck --format=tty \
         --shell=bash --external-sources \
         --enable add-default-case,avoid-nullary-conditions,check-unassigned-uppercase \
@@ -62,6 +65,9 @@ if [[ "${DISTRO_NV}" == "$PRIOR_FEDORA_NAME" ]]; then
     # Tests for lib.sh
     showrun ${SCRIPT_BASE}/lib.sh.t
 
+    # Tests for pr-should-link-jira
+    showrun ${SCRIPT_BASE}/pr-should-link-jira.t
+
     # Run this during daily cron job to prevent a GraphQL API change/breakage
     # from impacting every PR.  Down-side being if it does fail, a maintainer
     # will need to do some archaeology to find it.
@@ -72,42 +78,3 @@ if [[ "${DISTRO_NV}" == "$PRIOR_FEDORA_NAME" ]]; then
       showrun bash ${CIRRUS_WORKING_DIR}/.github/actions/check_cirrus_cron/test.sh
     fi
 fi
-
-msg "Checking 3rd party network service connectivity"
-# shellcheck disable=SC2154
-cat ${CIRRUS_WORKING_DIR}/${SCRIPT_BASE}/required_host_ports.txt | \
-    while read host port
-    do
-        if [[ "$port" -eq "443" ]]
-        then
-            echo "SSL/TLS to $host:$port"
-            echo -n '' | \
-                err_retry 9 1000 "" openssl s_client -quiet -no_ign_eof -connect $host:$port
-        else
-            echo "Connect to $host:$port"
-            err_retry 9 1000 1 nc -zv -w 13 $host $port
-        fi
-    done
-
-# Verify we can pull metadata from a few key testing images on quay.io
-# in the 'libpod' namespace.  This is mostly aimed at validating the
-# quay.io service is up and responsive.  Images were hand-picked with
-# grep -E -ro 'quay.io/libpod/.+:latest' test | sort -u
-TEST_IMGS=(\
-    alpine:latest
-    busybox:latest
-    alpine_labels:latest
-    alpine_nginx:latest
-    alpine_healthcheck:latest
-    badhealthcheck:latest
-    cirros:latest
-)
-
-msg "Checking quay.io test image accessibility"
-for testimg in "${TEST_IMGS[@]}"; do
-    fqin="quay.io/libpod/$testimg"
-    echo "    $fqin"
-    # Belt-and-suspenders: Catch skopeo (somehow) returning False or null
-    # in addition to "bad" (invalid) JSON.
-    skopeo inspect --retry-times 5 "docker://$fqin" | jq -e . > /dev/null
-done
