@@ -3,18 +3,16 @@
 package libpod
 
 import (
-	"errors"
 	"fmt"
-	"io/fs"
 	"os"
 	"path/filepath"
 	"runtime"
 	"strings"
 
 	"github.com/containers/podman/v5/libpod/define"
-	"github.com/containers/storage"
 	"github.com/sirupsen/logrus"
 	bolt "go.etcd.io/bbolt"
+	"go.podman.io/storage"
 )
 
 const (
@@ -237,20 +235,18 @@ func readOnlyValidateConfig(bucket *bolt.Bucket, toCheck dbConfigValidation) (bo
 	// which is symlinked to /var/home.
 	if toCheck.isPath {
 		if dbValue != "" {
-			// Ignore ENOENT on both, on a fresh system some paths
-			// may not exist this early in Libpod init.
-			dbVal, err := filepath.EvalSymlinks(dbValue)
-			if err != nil && !errors.Is(err, fs.ErrNotExist) {
+			checkedVal, err := evalSymlinksIfExists(dbValue)
+			if err != nil {
 				return false, fmt.Errorf("evaluating symlinks on DB %s path %q: %w", toCheck.name, dbValue, err)
 			}
-			dbValue = dbVal
+			dbValue = checkedVal
 		}
 		if ourValue != "" {
-			ourVal, err := filepath.EvalSymlinks(ourValue)
-			if err != nil && !errors.Is(err, fs.ErrNotExist) {
+			checkedVal, err := evalSymlinksIfExists(ourValue)
+			if err != nil {
 				return false, fmt.Errorf("evaluating symlinks on configured %s path %q: %w", toCheck.name, ourValue, err)
 			}
-			ourValue = ourVal
+			ourValue = checkedVal
 		}
 	}
 
@@ -283,7 +279,7 @@ func (s *BoltState) getDBCon() (*bolt.DB, error) {
 	// https://www.sqlite.org/src/artifact/c230a7a24?ln=994-1081
 	s.dbLock.Lock()
 
-	db, err := bolt.Open(s.dbPath, 0600, nil)
+	db, err := bolt.Open(s.dbPath, 0o600, nil)
 	if err != nil {
 		return nil, fmt.Errorf("opening database %s: %w", s.dbPath, err)
 	}
@@ -904,7 +900,7 @@ func (s *BoltState) removeContainer(ctr *Container, pod *Pod, tx *bolt.Tx) error
 	ctrExecSessionsBkt := ctrExists.Bucket(execBkt)
 	if ctrExecSessionsBkt != nil {
 		sessions := []string{}
-		err = ctrExecSessionsBkt.ForEach(func(id, value []byte) error {
+		err = ctrExecSessionsBkt.ForEach(func(id, _ []byte) error {
 			sessions = append(sessions, string(id))
 
 			return nil
@@ -923,7 +919,7 @@ func (s *BoltState) removeContainer(ctr *Container, pod *Pod, tx *bolt.Tx) error
 		return fmt.Errorf("container %s does not have a dependencies bucket: %w", ctr.ID(), define.ErrInternal)
 	}
 	deps := []string{}
-	err = ctrDepsBkt.ForEach(func(id, value []byte) error {
+	err = ctrDepsBkt.ForEach(func(id, _ []byte) error {
 		deps = append(deps, string(id))
 
 		return nil
@@ -1038,7 +1034,7 @@ func (s *BoltState) lookupContainerID(idOrName string, ctrBucket, namesBucket *b
 	// We were not given a full container ID or name.
 	// Search for partial ID matches.
 	exists := false
-	err := ctrBucket.ForEach(func(checkID, checkName []byte) error {
+	err := ctrBucket.ForEach(func(checkID, _ []byte) error {
 		if strings.HasPrefix(string(checkID), idOrName) {
 			if exists {
 				return fmt.Errorf("more than one result for container ID %s: %w", idOrName, define.ErrCtrExists)
