@@ -1,16 +1,19 @@
+//go:build !remote
+
 package libpod
 
 import (
 	"errors"
 	"fmt"
+	"maps"
 	"sort"
 	"strings"
 	"time"
 
-	"github.com/containers/common/pkg/config"
-	"github.com/containers/podman/v4/libpod/define"
-	"github.com/containers/podman/v4/libpod/lock"
+	"github.com/containers/podman/v5/libpod/define"
+	"github.com/containers/podman/v5/libpod/lock"
 	"github.com/opencontainers/runtime-spec/specs-go"
+	"go.podman.io/common/pkg/config"
 )
 
 // Pod represents a group of containers that are managed together.
@@ -81,6 +84,12 @@ type PodConfig struct {
 	// The pod's exit policy.
 	ExitPolicy config.PodExitPolicy `json:"ExitPolicy,omitempty"`
 
+	// The pod's restart policy
+	RestartPolicy string `json:"RestartPolicy,omitempty"`
+
+	// The max number of retries for a pod based on restart policy
+	RestartRetries *uint `json:"RestartRetries,omitempty"`
+
 	// ID of the pod's lock
 	LockID uint32 `json:"lockID"`
 
@@ -269,8 +278,8 @@ func (p *Pod) VolumesFrom() []string {
 	if err != nil {
 		return nil
 	}
-	if ctrs, ok := infra.config.Spec.Annotations[define.InspectAnnotationVolumesFrom]; ok {
-		return strings.Split(ctrs, ",")
+	if ctrs, ok := infra.config.Spec.Annotations[define.VolumesFromAnnotation]; ok {
+		return strings.Split(ctrs, ";")
 	}
 	return nil
 }
@@ -278,9 +287,7 @@ func (p *Pod) VolumesFrom() []string {
 // Labels returns the pod's labels
 func (p *Pod) Labels() map[string]string {
 	labels := make(map[string]string)
-	for key, value := range p.config.Labels {
-		labels[key] = value
-	}
+	maps.Copy(labels, p.config.Labels)
 
 	return labels
 }
@@ -355,9 +362,6 @@ func (p *Pod) CgroupPath() (string, error) {
 	if err := p.updatePod(); err != nil {
 		return "", err
 	}
-	if p.state.InfraContainerID == "" {
-		return "", fmt.Errorf("pod has no infra container: %w", define.ErrNoSuchCtr)
-	}
 	return p.state.CgroupPath, nil
 }
 
@@ -454,7 +458,7 @@ type PodContainerStats struct {
 }
 
 // GetPodStats returns the stats for each of its containers
-func (p *Pod) GetPodStats(previousContainerStats map[string]*define.ContainerStats) (map[string]*define.ContainerStats, error) {
+func (p *Pod) GetPodStats() (map[string]*define.ContainerStats, error) {
 	p.lock.Lock()
 	defer p.lock.Unlock()
 
@@ -467,15 +471,15 @@ func (p *Pod) GetPodStats(previousContainerStats map[string]*define.ContainerSta
 	}
 	newContainerStats := make(map[string]*define.ContainerStats)
 	for _, c := range containers {
-		newStats, err := c.GetContainerStats(previousContainerStats[c.ID()])
-		// If the container wasn't running, don't include it
-		// but also suppress the error
-		if err != nil && !errors.Is(err, define.ErrCtrStateInvalid) {
+		newStats, err := c.GetContainerStats(nil)
+		if err != nil {
+			// If the container wasn't running ignore it
+			if errors.Is(err, define.ErrCtrStateInvalid) || errors.Is(err, define.ErrCtrStopped) {
+				continue
+			}
 			return nil, err
 		}
-		if err == nil {
-			newContainerStats[c.ID()] = newStats
-		}
+		newContainerStats[c.ID()] = newStats
 	}
 	return newContainerStats, nil
 }
@@ -522,3 +526,10 @@ func (p *Pod) Config() (*PodConfig, error) {
 
 	return conf, err
 }
+
+// ConfigNoCopy returns the configuration used by the pod.
+// Note that the returned value is not a copy and must hence
+// only be used in a reading fashion.
+func (p *Pod) ConfigNoCopy() *PodConfig {
+	return p.config
+}
