@@ -17,16 +17,6 @@ import (
 	"time"
 
 	"github.com/containers/buildah/pkg/parse"
-	"github.com/containers/common/libimage"
-	"github.com/containers/common/libnetwork/network"
-	nettypes "github.com/containers/common/libnetwork/types"
-	"github.com/containers/common/pkg/cgroups"
-	"github.com/containers/common/pkg/config"
-	"github.com/containers/common/pkg/secrets"
-	systemdCommon "github.com/containers/common/pkg/systemd"
-	"github.com/containers/image/v5/pkg/sysregistriesv2"
-	is "github.com/containers/image/v5/storage"
-	"github.com/containers/image/v5/types"
 	"github.com/containers/podman/v5/libpod/define"
 	"github.com/containers/podman/v5/libpod/events"
 	"github.com/containers/podman/v5/libpod/lock"
@@ -34,19 +24,29 @@ import (
 	"github.com/containers/podman/v5/libpod/shutdown"
 	"github.com/containers/podman/v5/pkg/domain/entities"
 	"github.com/containers/podman/v5/pkg/domain/entities/reports"
-	artStore "github.com/containers/podman/v5/pkg/libartifact/store"
 	"github.com/containers/podman/v5/pkg/rootless"
 	"github.com/containers/podman/v5/pkg/systemd"
 	"github.com/containers/podman/v5/pkg/util"
-	"github.com/containers/storage"
-	"github.com/containers/storage/pkg/fileutils"
-	"github.com/containers/storage/pkg/lockfile"
-	"github.com/containers/storage/pkg/unshare"
 	"github.com/docker/docker/pkg/namesgenerator"
 	"github.com/hashicorp/go-multierror"
 	jsoniter "github.com/json-iterator/go"
 	spec "github.com/opencontainers/runtime-spec/specs-go"
 	"github.com/sirupsen/logrus"
+	"go.podman.io/common/libimage"
+	"go.podman.io/common/libnetwork/network"
+	nettypes "go.podman.io/common/libnetwork/types"
+	"go.podman.io/common/pkg/cgroups"
+	"go.podman.io/common/pkg/config"
+	artStore "go.podman.io/common/pkg/libartifact/store"
+	"go.podman.io/common/pkg/secrets"
+	systemdCommon "go.podman.io/common/pkg/systemd"
+	"go.podman.io/image/v5/pkg/sysregistriesv2"
+	is "go.podman.io/image/v5/storage"
+	"go.podman.io/image/v5/types"
+	"go.podman.io/storage"
+	"go.podman.io/storage/pkg/fileutils"
+	"go.podman.io/storage/pkg/lockfile"
+	"go.podman.io/storage/pkg/unshare"
 )
 
 // Set up the JSON library for all of Libpod
@@ -176,15 +176,6 @@ func NewRuntime(ctx context.Context, options ...RuntimeOption) (*Runtime, error)
 	return newRuntimeFromConfig(ctx, conf, options...)
 }
 
-// NewRuntimeFromConfig creates a new container runtime using the given
-// configuration file for its default configuration. Passed RuntimeOption
-// functions can be used to mutate this configuration further.
-// An error will be returned if the configuration file at the given path does
-// not exist or cannot be loaded
-func NewRuntimeFromConfig(ctx context.Context, userConfig *config.Config, options ...RuntimeOption) (*Runtime, error) {
-	return newRuntimeFromConfig(ctx, userConfig, options...)
-}
-
 func newRuntimeFromConfig(ctx context.Context, conf *config.Config, options ...RuntimeOption) (*Runtime, error) {
 	runtime := new(Runtime)
 
@@ -219,7 +210,7 @@ func newRuntimeFromConfig(ctx context.Context, conf *config.Config, options ...R
 		return nil, err
 	}
 
-	if err := shutdown.Register("libpod", func(sig os.Signal) error {
+	if err := shutdown.Register("libpod", func(_ os.Signal) error {
 		if runtime.store != nil {
 			_, _ = runtime.store.Shutdown(false)
 		}
@@ -357,7 +348,7 @@ func makeRuntime(ctx context.Context, runtime *Runtime) (retErr error) {
 	}
 
 	// Make the static files directory if it does not exist
-	if err := os.MkdirAll(runtime.config.Engine.StaticDir, 0700); err != nil {
+	if err := os.MkdirAll(runtime.config.Engine.StaticDir, 0o700); err != nil {
 		// The directory is allowed to exist
 		if !errors.Is(err, os.ErrExist) {
 			return fmt.Errorf("creating runtime static files directory %q: %w", runtime.config.Engine.StaticDir, err)
@@ -365,7 +356,7 @@ func makeRuntime(ctx context.Context, runtime *Runtime) (retErr error) {
 	}
 
 	// Create the TmpDir if needed
-	if err := os.MkdirAll(runtime.config.Engine.TmpDir, 0751); err != nil {
+	if err := os.MkdirAll(runtime.config.Engine.TmpDir, 0o751); err != nil {
 		return fmt.Errorf("creating runtime temporary files directory: %w", err)
 	}
 
@@ -373,7 +364,7 @@ func makeRuntime(ctx context.Context, runtime *Runtime) (retErr error) {
 	// This is not strictly necessary at this point, but the path not
 	// existing can cause troubles with DB path validation on OSTree based
 	// systems. Ref: https://github.com/containers/podman/issues/23515
-	if err := os.MkdirAll(runtime.config.Engine.VolumePath, 0700); err != nil {
+	if err := os.MkdirAll(runtime.config.Engine.VolumePath, 0o700); err != nil {
 		return fmt.Errorf("creating runtime volume path directory: %w", err)
 	}
 
@@ -895,7 +886,7 @@ func (r *Runtime) refresh(ctx context.Context, alivePath string) error {
 	}
 
 	// Create a file indicating the runtime is alive and ready
-	file, err := os.OpenFile(alivePath, os.O_RDONLY|os.O_CREATE, 0644)
+	file, err := os.OpenFile(alivePath, os.O_RDONLY|os.O_CREATE, 0o644)
 	if err != nil {
 		return fmt.Errorf("creating runtime status file: %w", err)
 	}
@@ -1313,10 +1304,21 @@ func (r *Runtime) PruneBuildContainers() ([]*reports.PruneReport, error) {
 
 // SystemCheck checks our storage for consistency, and depending on the options
 // specified, will attempt to remove anything which fails consistency checks.
-func (r *Runtime) SystemCheck(ctx context.Context, options entities.SystemCheckOptions) (entities.SystemCheckReport, error) {
+func (r *Runtime) SystemCheck(_ context.Context, options entities.SystemCheckOptions) (entities.SystemCheckReport, error) {
 	what := storage.CheckEverything()
 	if options.Quick {
-		what = storage.CheckMost()
+		// Turn off checking layer digests and layer contents to do quick check.
+		// This is not a complete check like storage.CheckEverything(), and may fail detecting
+		// whether a file is missing from the image or its content has changed.
+		// In some cases it's desirable to trade check thoroughness for speed.
+		what = &storage.CheckOptions{
+			LayerDigests:   false,
+			LayerMountable: true,
+			LayerContents:  false,
+			LayerData:      true,
+			ImageData:      true,
+			ContainerData:  true,
+		}
 	}
 	if options.UnreferencedLayerMaximumAge != nil {
 		tmp := *options.UnreferencedLayerMaximumAge
