@@ -1,5 +1,4 @@
 //go:build !remote
-// +build !remote
 
 package libpod
 
@@ -9,13 +8,12 @@ import (
 	"path/filepath"
 	"strings"
 
-	"github.com/containers/common/pkg/cgroups"
-	"github.com/containers/common/pkg/config"
-	"github.com/containers/podman/v4/libpod/define"
-	"github.com/containers/podman/v4/pkg/rootless"
-	"github.com/containers/podman/v4/utils"
+	"github.com/containers/podman/v5/libpod/define"
+	"github.com/containers/podman/v5/pkg/rootless"
 	spec "github.com/opencontainers/runtime-spec/specs-go"
 	"github.com/sirupsen/logrus"
+	"go.podman.io/common/pkg/cgroups"
+	"go.podman.io/common/pkg/config"
 )
 
 func (r *Runtime) platformMakePod(pod *Pod, resourceLimits *spec.LinuxResources) (string, error) {
@@ -43,6 +41,7 @@ func (r *Runtime) platformMakePod(pod *Pod, resourceLimits *spec.LinuxResources)
 						if err != nil {
 							return "", err
 						}
+						res.SkipDevices = true
 						// Need to both create and update the cgroup
 						// rather than create a new path in c/common for pod cgroup creation
 						// just create as if it is a ctr and then update figures out that we need to
@@ -97,7 +96,7 @@ func (p *Pod) removePodCgroup() error {
 	}
 	logrus.Debugf("Removing pod cgroup %s", p.state.CgroupPath)
 
-	cgroup, err := utils.GetOwnCgroup()
+	cgroup, err := cgroups.GetOwnCgroup()
 	if err != nil {
 		return err
 	}
@@ -106,7 +105,7 @@ func (p *Pod) removePodCgroup() error {
 	// current process out of it before the cgroup is destroyed.
 	if isSubDir(cgroup, string(filepath.Separator)+p.state.CgroupPath) {
 		parent := path.Dir(p.state.CgroupPath)
-		if err := utils.MoveUnderCgroup(parent, "cleanup", nil); err != nil {
+		if err := cgroups.MoveUnderCgroup(parent, "cleanup", nil); err != nil {
 			return err
 		}
 	}
