@@ -9,10 +9,13 @@ import (
 	"github.com/containers/podman/v5/libpod"
 	"github.com/containers/podman/v5/pkg/api/handlers"
 	"github.com/containers/podman/v5/pkg/api/handlers/utils"
+	"github.com/containers/podman/v5/pkg/api/handlers/utils/apiutil"
 	api "github.com/containers/podman/v5/pkg/api/types"
 	"github.com/containers/podman/v5/pkg/domain/entities"
 	"github.com/containers/podman/v5/pkg/domain/infra/abi"
 	docker "github.com/docker/docker/api/types"
+	"github.com/docker/docker/api/types/build"
+	"github.com/docker/docker/api/types/container"
 	dockerImage "github.com/docker/docker/api/types/image"
 	"github.com/docker/docker/api/types/volume"
 )
@@ -39,14 +42,18 @@ func GetDiskUsage(w http.ResponseWriter, r *http.Request) {
 			RepoTags:    []string{o.Tag},
 			SharedSize:  o.SharedSize,
 			Size:        o.Size,
-			VirtualSize: o.Size - o.UniqueSize,
 		}
+
+		if _, err := apiutil.SupportedVersion(r, "<1.44.0"); err == nil {
+			t.VirtualSize = o.Size - o.UniqueSize //nolint:staticcheck // Deprecated field
+		}
+
 		imgs[i] = &t
 	}
 
-	ctnrs := make([]*docker.Container, len(df.Containers))
+	ctnrs := make([]*container.Summary, len(df.Containers))
 	for i, o := range df.Containers {
-		t := docker.Container{
+		t := container.Summary{
 			ID:         o.ContainerID,
 			Names:      []string{o.Names},
 			Image:      o.Image,
@@ -89,11 +96,13 @@ func GetDiskUsage(w http.ResponseWriter, r *http.Request) {
 	}
 
 	utils.WriteResponse(w, http.StatusOK, handlers.DiskUsage{DiskUsage: docker.DiskUsage{
-		LayersSize:  df.ImagesSize,
-		Images:      imgs,
-		Containers:  ctnrs,
-		Volumes:     vols,
-		BuildCache:  []*docker.BuildCache{},
-		BuilderSize: 0,
+		// BuilderSize was explicitly omitted since Docker deprecated its in ver 1.42
+		// and suggests to use BuildCache.
+		// https://docs.docker.com/reference/api/engine/version-history/#v142-api-changes
+		LayersSize: df.ImagesSize,
+		Images:     imgs,
+		Containers: ctnrs,
+		Volumes:    vols,
+		BuildCache: []*build.CacheRecord{},
 	}})
 }
