@@ -4,17 +4,17 @@
 package swagger
 
 import (
-	"github.com/containers/common/libnetwork/types"
-	"github.com/containers/image/v5/manifest"
 	"github.com/containers/podman/v5/libpod/define"
 	"github.com/containers/podman/v5/pkg/api/handlers"
 	"github.com/containers/podman/v5/pkg/domain/entities"
 	"github.com/containers/podman/v5/pkg/domain/entities/reports"
 	"github.com/containers/podman/v5/pkg/inspect"
-	dockerAPI "github.com/docker/docker/api/types"
+	"github.com/docker/docker/api/types/container"
 	dockerImage "github.com/docker/docker/api/types/image"
 	"github.com/docker/docker/api/types/network"
 	"github.com/docker/docker/api/types/volume"
+	"go.podman.io/common/libnetwork/types"
+	"go.podman.io/image/v5/manifest"
 )
 
 // Image Tree
@@ -125,7 +125,7 @@ type inspectImageResponseLibpod struct {
 // swagger:response
 type containerInspectResponse struct {
 	// in:body
-	Body dockerAPI.ContainerJSON
+	Body container.InspectResponse
 }
 
 // List processes in container
@@ -324,9 +324,13 @@ type containerCreateResponse struct {
 	Body entities.ContainerCreateResponse
 }
 
+// Update container
+// swagger:response
 type containerUpdateResponse struct {
 	// in:body
-	ID string
+	Body struct {
+		ID string
+	}
 }
 
 // Wait container
@@ -474,3 +478,52 @@ type networkPruneResponse struct {
 	// in:body
 	Body []entities.NetworkPruneReport
 }
+
+// Inspect Artifact
+// swagger:response
+type inspectArtifactResponse struct {
+	// in:body
+	Body entities.ArtifactInspectReport
+}
+
+// Artifact list
+// swagger:response
+type artifactListResponse struct {
+	// in:body
+	Body []entities.ArtifactListReport
+}
+
+// Artifact Pull
+// swagger:response
+type artifactPullResponse struct {
+	// in:body
+	Body entities.ArtifactPullReport
+}
+
+// Artifact Remove
+// swagger:response
+type artifactRemoveResponse struct {
+	// in:body
+	Body entities.ArtifactRemoveReport
+}
+
+// Artifact Add
+// swagger:response
+type artifactAddResponse struct {
+	// in:body
+	Body entities.ArtifactAddReport
+}
+
+// Artifact Push
+// swagger:response
+type artifactPushResponse struct {
+	// in:body
+	Body entities.ArtifactPushReport
+}
+
+// Quadlet list
+// swagger:response
+type quadletListResponse struct {
+	// in:body
+	Body []entities.ListQuadlet
+}
