@@ -1,5 +1,4 @@
 //go:build !windows
-// +build !windows
 
 package images
 
@@ -11,7 +10,7 @@ import (
 func checkHardLink(fi os.FileInfo) (devino, bool) {
 	st := fi.Sys().(*syscall.Stat_t)
 	return devino{
-		Dev: uint64(st.Dev),
-		Ino: uint64(st.Ino),
+		Dev: uint64(st.Dev), //nolint:unconvert,nolintlint
+		Ino: st.Ino,
 	}, st.Nlink > 1
 }
