@@ -12,8 +12,6 @@ import (
 	"syscall"
 	"time"
 
-	"github.com/containers/common/pkg/config"
-	"github.com/containers/common/pkg/strongunits"
 	gvproxy "github.com/containers/gvisor-tap-vsock/pkg/types"
 	"github.com/containers/podman/v5/pkg/machine"
 	"github.com/containers/podman/v5/pkg/machine/define"
@@ -23,6 +21,8 @@ import (
 	"github.com/containers/podman/v5/pkg/systemd/parser"
 	vfConfig "github.com/crc-org/vfkit/pkg/config"
 	"github.com/sirupsen/logrus"
+	"go.podman.io/common/pkg/config"
+	"go.podman.io/common/pkg/strongunits"
 )
 
 const applehvMACAddress = "5a:94:ef:e4:0c:ee"
@@ -78,7 +78,7 @@ func GenerateSystemDFilesForVirtiofsMounts(mounts []machine.VirtIoFs) ([]ignitio
 		mountUnit.Add("Mount", "Where", "%s")
 		mountUnit.Add("Mount", "Type", "virtiofs")
 		mountUnit.Add("Mount", "Options", fmt.Sprintf("context=\"%s\"", machine.NFSSELinuxContext))
-		mountUnit.Add("Install", "WantedBy", "multi-user.target")
+		mountUnit.Add("Install", "WantedBy", "local-fs.target")
 		mountUnitFile, err := mountUnit.ToString()
 		if err != nil {
 			return nil, err
@@ -102,7 +102,7 @@ func GenerateSystemDFilesForVirtiofsMounts(mounts []machine.VirtIoFs) ([]ignitio
 	immutableRootOff.Add("Service", "Type", "oneshot")
 	immutableRootOff.Add("Service", "ExecStart", "chattr -i /")
 
-	immutableRootOff.Add("Install", "WantedBy", "remote-fs-pre.target")
+	immutableRootOff.Add("Install", "WantedBy", "local-fs-pre.target")
 	immutableRootOffFile, err := immutableRootOff.ToString()
 	if err != nil {
 		return nil, err
@@ -118,12 +118,12 @@ func GenerateSystemDFilesForVirtiofsMounts(mounts []machine.VirtIoFs) ([]ignitio
 	immutableRootOn := parser.NewUnitFile()
 	immutableRootOn.Add("Unit", "Description", "Set / back to immutable after mounts are done")
 	immutableRootOn.Add("Unit", "DefaultDependencies", "no")
-	immutableRootOn.Add("Unit", "After", "remote-fs.target")
+	immutableRootOn.Add("Unit", "After", "local-fs.target")
 
 	immutableRootOn.Add("Service", "Type", "oneshot")
 	immutableRootOn.Add("Service", "ExecStart", "chattr +i /")
 
-	immutableRootOn.Add("Install", "WantedBy", "remote-fs.target")
+	immutableRootOn.Add("Install", "WantedBy", "local-fs.target")
 	immutableRootOnFile, err := immutableRootOn.ToString()
 	if err != nil {
 		return nil, err
@@ -225,6 +225,13 @@ func StartGenericAppleVM(mc *vmconfigs.MachineConfig, cmdBinary string, bootload
 		cmd.Args = append(cmd.Args, "--gui") // add command line switch to pop the gui open
 	}
 
+	if mc.LibKrunHypervisor != nil {
+		// Nested Virtualization requires an M3 chip or newer, and to be running
+		// macOS 15+. If those requirements are not met, then krunkit will ignore the
+		// argument and keep Nested Virtualization disabled.
+		cmd.Args = append(cmd.Args, "--nested")
+	}
+
 	if mc.IsFirstBoot() {
 		// If this is the first boot of the vm, we need to add the vsock
 		// device to vfkit so we can inject the ignition file
@@ -281,7 +288,7 @@ func StartGenericAppleVM(mc *vmconfigs.MachineConfig, cmdBinary string, bootload
 		if err != nil {
 			return nil, nil, err
 		}
-		err = os.Chmod(kdFile.Path, 0744)
+		err = os.Chmod(kdFile.Path, 0o744)
 		if err != nil {
 			return nil, nil, err
 		}
