@@ -12,22 +12,16 @@ import (
 	"strings"
 	"time"
 
-	"github.com/containers/common/pkg/strongunits"
 	"github.com/containers/podman/v5/pkg/machine/compression"
 	"github.com/containers/podman/v5/pkg/machine/define"
-	"github.com/containers/podman/v5/pkg/machine/env"
 	"github.com/containers/podman/v5/pkg/machine/vmconfigs"
 	"github.com/sirupsen/logrus"
+	"go.podman.io/common/pkg/strongunits"
 )
 
-const (
-	DefaultMachineName string = "podman-machine-default"
-	apiUpTimeout              = 20 * time.Second
-)
+const apiUpTimeout = 20 * time.Second
 
-var (
-	ForwarderBinaryName = "gvproxy"
-)
+var ForwarderBinaryName = "gvproxy"
 
 type Download struct {
 	Arch                  string
@@ -58,6 +52,7 @@ type ListResponse struct {
 	VMType             string
 	CPUs               uint64
 	Memory             strongunits.MiB
+	Swap               strongunits.MiB
 	DiskSize           strongunits.GiB
 	Port               int
 	RemoteUsername     string
@@ -71,8 +66,9 @@ type SSHOptions struct {
 }
 
 type StartOptions struct {
-	NoInfo bool
-	Quiet  bool
+	NoInfo  bool
+	Quiet   bool
+	Rosetta bool
 }
 
 type StopOptions struct{}
@@ -117,6 +113,12 @@ type InspectInfo struct {
 	State              define.Status
 	UserModeNetworking bool
 	Rootful            bool
+	Rosetta            bool
+}
+
+type InternalInspectInfo struct {
+	InspectInfo
+	Mounts []*vmconfigs.Mount
 }
 
 // ImageConfig describes the bootable image for the VM
@@ -148,61 +150,6 @@ const (
 	DockerGlobal
 )
 
-// TODO THis should be able to be removed once WSL is refactored for podman5
-type Virtualization struct {
-	artifact    define.Artifact
-	compression compression.ImageCompression
-	format      define.ImageFormat
-	vmKind      define.VMType
-}
-
-func (p *Virtualization) Artifact() define.Artifact {
-	return p.artifact
-}
-
-func (p *Virtualization) Compression() compression.ImageCompression {
-	return p.compression
-}
-
-func (p *Virtualization) Format() define.ImageFormat {
-	return p.format
-}
-
-func (p *Virtualization) VMType() define.VMType {
-	return p.vmKind
-}
-
-func (p *Virtualization) NewDownload(vmName string) (Download, error) {
-	cacheDir, err := env.GetCacheDir(p.VMType())
-	if err != nil {
-		return Download{}, err
-	}
-
-	dataDir, err := env.GetDataDir(p.VMType())
-	if err != nil {
-		return Download{}, err
-	}
-
-	return Download{
-		Artifact:        p.Artifact(),
-		CacheDir:        cacheDir,
-		CompressionType: p.Compression(),
-		DataDir:         dataDir,
-		Format:          p.Format(),
-		VMKind:          p.VMType(),
-		VMName:          vmName,
-	}, nil
-}
-
-func NewVirtualization(artifact define.Artifact, compression compression.ImageCompression, format define.ImageFormat, vmKind define.VMType) Virtualization {
-	return Virtualization{
-		artifact,
-		compression,
-		format,
-		vmKind,
-	}
-}
-
 func dialSocket(socket string, timeout time.Duration) (net.Conn, error) {
 	scheme := "unix"
 	if strings.Contains(socket, "://") {
@@ -267,7 +214,7 @@ func WaitAndPingAPI(sock string) {
 	if err == nil {
 		defer resp.Body.Close()
 	}
-	if err != nil || resp.StatusCode != 200 {
+	if err != nil || resp.StatusCode != http.StatusOK {
 		logrus.Warn("API socket failed ping test")
 	}
 }
