@@ -9,7 +9,6 @@ import (
 	"strings"
 	"time"
 
-	"github.com/containers/common/pkg/strongunits"
 	"github.com/containers/podman/v5/pkg/machine/define"
 	"github.com/containers/podman/v5/utils"
 	. "github.com/onsi/ginkgo/v2"
@@ -17,6 +16,7 @@ import (
 	. "github.com/onsi/gomega/gexec"
 	"github.com/shirou/gopsutil/v4/mem"
 	"github.com/sirupsen/logrus"
+	"go.podman.io/common/pkg/strongunits"
 )
 
 var _ = Describe("podman machine init", func() {
@@ -239,6 +239,16 @@ var _ = Describe("podman machine init", func() {
 		}
 		Expect(testMachine.SSHConfig.RemoteUsername).To(Equal(remoteUsername))
 
+		s := new(startMachine)
+		session, err = mb.setCmd(s).run()
+		Expect(err).ToNot(HaveOccurred())
+		Expect(session).To(Exit(0))
+
+		ssh := sshMachine{}
+		sshSession, err := mb.setName(mb.name).setCmd(ssh.withSSHCommand([]string{"loginctl -P Linger show-user " + remoteUsername})).run()
+		Expect(err).ToNot(HaveOccurred())
+		Expect(sshSession).To(Exit(0))
+		Expect(sshSession.outputToString()).To(ContainSubstring("yes"))
 	})
 
 	It("machine init with cpus, disk size, memory, timezone", func() {
@@ -280,6 +290,29 @@ var _ = Describe("podman machine init", func() {
 		Expect(err).ToNot(HaveOccurred())
 		Expect(timezoneSession).To(Exit(0))
 		Expect(timezoneSession.outputToString()).To(ContainSubstring("HST"))
+
+		sshTimezone = sshMachine{}
+		timezoneSession, err = mb.setName(name).setCmd(sshTimezone.withSSHCommand([]string{"timedatectl show --property Timezone"})).run()
+		Expect(err).ToNot(HaveOccurred())
+		Expect(timezoneSession).To(Exit(0))
+		Expect(timezoneSession.outputToString()).To(ContainSubstring("Pacific/Honolulu"))
+	})
+
+	It("machine init with swap", func() {
+		skipIfWSL("Configuring swap is not supported on WSL")
+		name := randomString()
+		i := new(initMachine)
+		session, err := mb.setName(name).setCmd(i.withImage(mb.imagePath).withSwap(2048).withNow()).run()
+		Expect(err).ToNot(HaveOccurred())
+		Expect(session).To(Exit(0))
+
+		ssh := &sshMachine{}
+		sshSession, err := mb.setName(name).setCmd(ssh.withSSHCommand([]string{"zramctl -bo DISKSIZE"})).run()
+		Expect(err).ToNot(HaveOccurred())
+		Expect(sshSession).To(Exit(0))
+
+		// 2147483648 bytes = 2048MiB
+		Expect(sshSession.outputToString()).To(ContainSubstring("2147483648"))
 	})
 
 	It("machine init with volume", func() {
@@ -382,7 +415,6 @@ var _ = Describe("podman machine init", func() {
 		output := strings.TrimSpace(sshSession2.outputToString())
 		Expect(output).To(HavePrefix("/run/user"))
 		Expect(output).To(HaveSuffix("/podman/podman.sock"))
-
 	})
 
 	It("machine init rootful with docker.sock check", func() {
@@ -464,7 +496,7 @@ var _ = Describe("podman machine init", func() {
 	It("verify a podman 4 config does not break podman 5", func() {
 		vmName := "foobar-machine"
 		configDir := filepath.Join(testDir, ".config", "containers", "podman", "machine", testProvider.VMType().String())
-		if err := os.MkdirAll(configDir, 0755); err != nil {
+		if err := os.MkdirAll(configDir, 0o755); err != nil {
 			Expect(err).ToNot(HaveOccurred())
 		}
 		f, err := os.Create(filepath.Join(configDir, fmt.Sprintf("%s.json", vmName)))
@@ -510,6 +542,7 @@ var _ = Describe("podman machine init", func() {
 	})
 
 	It("machine init with rosetta=true", func() {
+		Skip("rosetta currently hard disabled https://github.com/containers/podman-machine-os/pull/134")
 		skipIfVmtype(define.QemuVirt, "Test is only for AppleHv")
 		skipIfVmtype(define.WSLVirt, "Test is only for AppleHv")
 		skipIfVmtype(define.HyperVVirt, "Test is only for AppleHv")
@@ -563,10 +596,10 @@ var _ = Describe("podman machine init", func() {
 			Skip("Test is only for AppleHv with arm64 architecture")
 		}
 		configDir := filepath.Join(testDir, ".config", "containers")
-		err := os.MkdirAll(configDir, 0755)
+		err := os.MkdirAll(configDir, 0o755)
 		Expect(err).ToNot(HaveOccurred())
 
-		err = os.WriteFile(filepath.Join(configDir, "containers.conf"), rosettaConfig, 0644)
+		err = os.WriteFile(filepath.Join(configDir, "containers.conf"), rosettaConfig, 0o644)
 		Expect(err).ToNot(HaveOccurred())
 
 		i := initMachine{}
