@@ -10,26 +10,10 @@ import (
 	"time"
 
 	"github.com/containers/podman/v5/pkg/machine/define"
-	"github.com/containers/storage/pkg/fileutils"
 	"github.com/sirupsen/logrus"
+	"go.podman.io/storage/pkg/fileutils"
 )
 
-// SetSocket creates a new machine file for the socket and assigns it to
-// `socketLoc`
-func SetSocket(socketLoc *define.VMFile, path string, symlink *string) error {
-	socket, err := define.NewMachineFile(path, symlink)
-	if err != nil {
-		return err
-	}
-	*socketLoc = *socket
-	return nil
-}
-
-// ReadySocketPath returns the filepath for the ready socket
-func ReadySocketPath(runtimeDir, machineName string) string {
-	return filepath.Join(runtimeDir, fmt.Sprintf("%s_ready.sock", machineName))
-}
-
 // ListenAndWaitOnSocket waits for a new connection to the listener and sends
 // any error back through the channel. ListenAndWaitOnSocket is intended to be
 // used as a goroutine
@@ -53,7 +37,7 @@ func ListenAndWaitOnSocket(errChan chan<- error, listener net.Listener) {
 
 // DialSocketWithBackoffs attempts to connect to the socket in maxBackoffs attempts
 func DialSocketWithBackoffs(maxBackoffs int, backoff time.Duration, socketPath string) (conn net.Conn, err error) {
-	for i := 0; i < maxBackoffs; i++ {
+	for i := range maxBackoffs {
 		if i > 0 {
 			time.Sleep(backoff)
 			backoff *= 2
@@ -78,7 +62,7 @@ func DialSocketWithBackoffsAndProcCheck(
 	procPid int,
 	errBuf *bytes.Buffer,
 ) (conn net.Conn, err error) {
-	for i := 0; i < maxBackoffs; i++ {
+	for i := range maxBackoffs {
 		if i > 0 {
 			time.Sleep(backoff)
 			backoff *= 2
@@ -101,7 +85,7 @@ func DialSocketWithBackoffsAndProcCheck(
 func WaitForSocketWithBackoffs(maxBackoffs int, backoff time.Duration, socketPath string, name string) error {
 	backoffWait := backoff
 	logrus.Debugf("checking that %q socket is ready", name)
-	for i := 0; i < maxBackoffs; i++ {
+	for range maxBackoffs {
 		err := fileutils.Exists(socketPath)
 		if err == nil {
 			return nil
