@@ -8,10 +8,10 @@ import (
 	"strconv"
 	"strings"
 
-	"github.com/containers/common/libnetwork/types"
-	"github.com/containers/common/pkg/config"
-	storageTypes "github.com/containers/storage/types"
 	"github.com/sirupsen/logrus"
+	"go.podman.io/common/libnetwork/types"
+	"go.podman.io/common/pkg/config"
+	storageTypes "go.podman.io/storage/types"
 )
 
 // ReadPodIDFile reads the specified file and returns its content (i.e., first
@@ -62,7 +62,7 @@ func CreateExpose(expose []string) (map[uint16]string, error) {
 		}
 
 		var index uint16
-		for index = 0; index < len; index++ {
+		for index = range len {
 			portNum := start + index
 			protocols, ok := toReturn[portNum]
 			if !ok {
@@ -261,7 +261,7 @@ func parseAndValidatePort(port string) (uint16, error) {
 	return uint16(num), nil
 }
 
-func CreateExitCommandArgs(storageConfig storageTypes.StoreOptions, config *config.Config, syslog, rm, exec bool) ([]string, error) {
+func CreateExitCommandArgs(storageConfig storageTypes.StoreOptions, config *config.Config, syslog, rm, rmi, exec bool) ([]string, error) {
 	// We need a cleanup process for containers in the current model.
 	// But we can't assume that the caller is Podman - it could be another
 	// user of the API.
@@ -285,6 +285,9 @@ func CreateExitCommandArgs(storageConfig storageTypes.StoreOptions, config *conf
 		"--db-backend", config.Engine.DBBackend,
 		fmt.Sprintf("--transient-store=%t", storageConfig.TransientStore),
 	}
+	for _, dir := range config.Engine.HooksDir.Get() {
+		command = append(command, []string{"--hooks-dir", dir}...)
+	}
 	if storageConfig.ImageStore != "" {
 		command = append(command, []string{"--imagestore", storageConfig.ImageStore}...)
 	}
@@ -304,12 +307,25 @@ func CreateExitCommandArgs(storageConfig storageTypes.StoreOptions, config *conf
 	if syslog {
 		command = append(command, "--syslog")
 	}
-	command = append(command, []string{"container", "cleanup"}...)
+
+	// Make sure that loaded containers.conf modules are passed down to the
+	// callback as well.
+	for _, module := range config.LoadedModules() {
+		command = append(command, "--module", module)
+	}
+
+	// --stopped-only is used to ensure we only cleanup stopped containers and do not race
+	// against other processes that did a cleanup() + init() again before we had the chance to run
+	command = append(command, []string{"container", "cleanup", "--stopped-only"}...)
 
 	if rm {
 		command = append(command, "--rm")
 	}
 
+	if rmi {
+		command = append(command, "--rmi")
+	}
+
 	// This has to be absolutely last, to ensure that the exec session ID
 	// will be added after it by Libpod.
 	if exec {
