@@ -18,13 +18,13 @@ import (
 
 func createContainersConfFileWithDevices(pTest *PodmanTestIntegration, devices string, cdiSpecDirs []string) {
 	configPath := filepath.Join(pTest.TempDir, "containers.conf")
-	containersConf := []byte(fmt.Sprintf("[containers]\ndevices = [%s]\n", devices))
+	containersConf := fmt.Appendf(nil, "[containers]\ndevices = [%s]\n", devices)
 	if len(cdiSpecDirs) > 0 {
 		quoted := make([]string, len(cdiSpecDirs))
 		for i, dir := range cdiSpecDirs {
 			quoted[i] = fmt.Sprintf("%q", dir)
 		}
-		containersConf = append(containersConf, []byte(fmt.Sprintf("[engine]\ncdi_spec_dirs = [%s]\n", strings.Join(quoted, ", ")))...)
+		containersConf = append(containersConf, fmt.Appendf(nil, "[engine]\ncdi_spec_dirs = [%s]\n", strings.Join(quoted, ", "))...)
 	}
 	err := os.WriteFile(configPath, containersConf, os.ModePerm)
 	Expect(err).ToNot(HaveOccurred())
@@ -50,7 +50,10 @@ var _ = Describe("Podman run device", func() {
 		Expect(session).Should(ExitCleanly())
 		if !isRootless() {
 			// Kernel 6.9.0 (2024-03) requires SYSLOG
-			session = podmanTest.Podman([]string{"run", "-q", "--security-opt", "label=disable", "--device", "/dev/kmsg", "--cap-add", "SYS_ADMIN,SYSLOG", ALPINE, "head", "-n", "1", "/dev/kmsg"})
+			// Do not read any data from the device (thus the -n 0), because there is a rare race condition that happens
+			// when another writes to the ring buffer when the device is already opened and that causes the following test
+			// to fail: https://github.com/containers/podman/issues/23882.
+			session = podmanTest.Podman([]string{"run", "-q", "--security-opt", "label=disable", "--device", "/dev/kmsg", "--cap-add", "SYS_ADMIN,SYSLOG", ALPINE, "head", "-n", "0", "/dev/kmsg"})
 			session.WaitWithDefaultTimeout()
 			Expect(session).Should(ExitCleanly())
 		}
@@ -79,7 +82,13 @@ var _ = Describe("Podman run device", func() {
 	It("podman run device rename and bad permission test", func() {
 		session := podmanTest.Podman([]string{"run", "-q", "--security-opt", "label=disable", "--device", "/dev/kmsg:/dev/kmsg1:rd", ALPINE, "true"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(ExitWithError(125, "invalid device mode: rd"))
+		Expect(session).Should(ExitWithError(125, "invalid device mode \"rd\" in device \"/dev/kmsg:/dev/kmsg1:rd\""))
+	})
+
+	It("podman run device with empty mode test", func() {
+		session := podmanTest.Podman([]string{"run", "-q", "--device", "/dev/fuse::", ALPINE, "true"})
+		session.WaitWithDefaultTimeout()
+		Expect(session).Should(ExitWithError(125, "empty device mode in device specification: /dev/fuse::"))
 	})
 
 	It("podman run device host device and container device parameter are directories", func() {
@@ -152,9 +161,12 @@ var _ = Describe("Podman run device", func() {
 	})
 
 	It("podman run cannot access non default devices", func() {
-		session := podmanTest.Podman([]string{"run", "-v /dev:/dev-host", ALPINE, "head", "-1", "/dev-host/kmsg"})
+		// Unlikely to happen but do not read any data from the device (thus the -n 0), because there is a rare
+		// race condition that happens so the test would fail for the rare race condition instead of a failure
+		// reported by open(). More details: https://github.com/containers/podman/issues/23882.
+		session := podmanTest.Podman([]string{"run", "-v", "/dev:/dev-host", ALPINE, "head", "-n0", "/dev-host/kmsg"})
 		session.WaitWithDefaultTimeout()
-		Expect(session).Should(Not(ExitCleanly()))
+		Expect(session).To(ExitWithErrorRegex(1, "head: /dev-host/kmsg: (Operation not permitted|Permission denied)"))
 	})
 
 })
